@@ -3,7 +3,7 @@
                            Coda File System
                               Release 5
 
-          Copyright (c) 1987-1999 Carnegie Mellon University
+          Copyright (c) 1987-2008 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -356,13 +356,13 @@ static int get_valid_parm(argc, argv, pdatalen,
 	       *pdatalen, *pdatalen);
         printf("  starting address of rvm: %#10lx (%10lu)\n",
 	       (unsigned long)*pstatic_addr, (unsigned long)*pstatic_addr);
-        printf("                 heap len: %#10x (%10d)\n",
+        printf("                 heap len: %#10lx (%10ld)\n",
 	       *phlen, *phlen);
-        printf("               static len: %#10x (%10d)\n",
+        printf("               static len: %#10lx (%10ld)\n",
 	       *pslen, *pslen);
-        printf("                   nlists: %#10x (%10d)\n",
+        printf("                   nlists: %#10lx (%10ld)\n",
 	       *pnlists, *pnlists);
-        printf("               chunk size: %#10x (%10d)\n",
+        printf("               chunk size: %#10lx (%10ld)\n",
 	       *pchunksize, *pchunksize);
         printf("Do you agree with these parameters ? (y|n|q) ");
 	fgets(string,80,stdin);
