@@ -3,7 +3,7 @@
                            Coda File System
                               Release 5
 
-          Copyright (c) 1987-1999 Carnegie Mellon University
+          Copyright (c) 1987-2008 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -590,7 +590,7 @@ void do_trans(block,range_list,do_flush,id)
     int             start,finish,temp,i,j;
     int             n_ranges;
     block_t         *range;
-    char            *save_area;
+    char            *save_area = NULL;
     char            new_val;
     rvm_bool_t      do_abort = rvm_false;
     rvm_tid_t       tid;
